package com.link.core.util.dynamicredis;

import com.link.core.util.SpringUtil;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import redis.clients.jedis.HostAndPort;
import redis.clients.jedis.JedisCluster;
import redis.clients.jedis.JedisPoolConfig;

public class DynamicJedisClusterSingleton {
   private static final Logger logger = LogManager.getLogger(DynamicJedisClusterSingleton.class);
   private static volatile DynamicJedisClusterSingleton instance;
   private ConcurrentHashMap<String, JedisCluster> jedisClusterMap = new ConcurrentHashMap(4);

   public static DynamicJedisClusterSingleton getInstance() {
      if (null == instance) {
         logger.info("初始化redis线程池！");
         Class var0 = DynamicJedisClusterSingleton.class;
         synchronized(DynamicJedisClusterSingleton.class) {
            if (null == instance) {
               instance = new DynamicJedisClusterSingleton();
            }
         }
      }

      return instance;
   }

   public DynamicJedisClusterSingleton() {
      DynamicRedisProps dynamicRedisProps = (DynamicRedisProps)SpringUtil.getBean(DynamicRedisProps.class);
      List<String> names = dynamicRedisProps.getName();

      for(int i = 0; i < names.size(); ++i) {
         JedisCluster jedisCluster = this.getSingleClusterInfo(dynamicRedisProps, i);
         this.jedisClusterMap.put(names.get(i), jedisCluster);
      }

   }

   private JedisCluster getSingleClusterInfo(DynamicRedisProps dynamicRedisProps, int index) {
      JedisPoolConfig poolConfig = new JedisPoolConfig();
      poolConfig.setMaxIdle(500);
      poolConfig.setMaxTotal(3000);
      poolConfig.setMinIdle(50);
      String redisClusterNodes = null;

      try {
         redisClusterNodes = (String)dynamicRedisProps.getNodes().get(index);
      } catch (Exception var16) {
         redisClusterNodes = (String)dynamicRedisProps.getNodes().get(0);
      }

      Integer redisClusterCommandTimeout = null;

      try {
         redisClusterCommandTimeout = (Integer)dynamicRedisProps.getCommandTimeout().get(index);
      } catch (Exception var15) {
         redisClusterCommandTimeout = (Integer)dynamicRedisProps.getCommandTimeout().get(0);
      }

      String redisClusterPassword = null;

      try {
         redisClusterPassword = (String)dynamicRedisProps.getPassword().get(index);
      } catch (Exception var14) {
         redisClusterPassword = (String)dynamicRedisProps.getPassword().get(0);
      }

      logger.error("获取到的redis#cluster节点：" + redisClusterNodes);
      String[] serverArray = redisClusterNodes.split(",");
      Set<HostAndPort> nodes = new HashSet();
      String[] var9 = serverArray;
      int var10 = serverArray.length;

      for(int var11 = 0; var11 < var10; ++var11) {
         String ipPort = var9[var11];
         String[] ipPortPair = ipPort.split(":");
         nodes.add(new HostAndPort(ipPortPair[0].trim(), Integer.valueOf(ipPortPair[1].trim())));
      }

      JedisCluster jedisCluster = new JedisCluster(nodes, redisClusterCommandTimeout, 10000, 3, redisClusterPassword, poolConfig);
      return jedisCluster;
   }

   public JedisCluster getJedisCluster(RedisSource redisSource) {
      return (JedisCluster)this.jedisClusterMap.get(redisSource.getName());
   }
}
